package com.chelvc.cloud.maintain.controller;

import java.util.List;
import javax.validation.Valid;
import javax.validation.constraints.Min;
import javax.validation.constraints.NotEmpty;

import com.chelvc.cloud.vehicle.client.OmsCartItemClient;
import com.chelvc.cloud.vehicle.client.dto.MerchantCartItemDTO;
import com.chelvc.cloud.vehicle.client.dto.OmsCartItemDTO;
import com.chelvc.cloud.vehicle.client.param.OmsCartItemModifyParam;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

/**
 * 购物车接口
 *
 * @author liude
 * @Date 2023/11/19
 **/
@Validated
@RestController
@ResponseWrapping
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class CartItemController {
    private final OmsCartItemClient omsCartItemClient;

    /**
     * 新增购物车商品
     *
     * @param param 新增参数
     * @return 购物车主键
     */
    @PostMapping("/cartItem")
    public Integer addCartItem(@RequestBody @Valid OmsCartItemModifyParam param) {
        return this.omsCartItemClient.add(param);
    }

    /**
     * 获取购物车商品列表
     *
     * @return 购物车主键
     */
    @GetMapping("/listCartItem")
    public List<OmsCartItemDTO> listCartItem() {
        return this.omsCartItemClient.listCartItem();
    }

    /**
     * 修改购物车商品的数量
     *
     * @return 购物车主键
     */
    @GetMapping("/cartItem/{id}")
    public Integer updateCartItem(@PathVariable("id") @Min
            (value = 1, message = "优惠券主键不能小于1") Long id, Integer quantity) {
        return this.omsCartItemClient.updateQuantity(id, quantity);
    }

    /**
     * 删除购物车
     *
     * @return 购物车主键
     */
    @PostMapping("/cartItem/deleteCartItem/{ids}")
    public void deleteCartItem(@PathVariable("ids") @NotEmpty(message = "购物车ID不能为空") List<Long> ids) {
        this.omsCartItemClient.delete(ids);
    }

    /**
     * 修改购物车中商品的规格
     *
     * @param param 新增参数
     * @return 购物车主键
     */
    @PostMapping("/cartItem/updateAttr")
    public Integer updateAttr(@RequestBody @Valid OmsCartItemModifyParam param) {
        return this.omsCartItemClient.updateAttr(param);
    }

    /**
     * 获取商家购物车商品列表
     *
     * @return 购物车主键
     */
    @GetMapping("/listCartItem/{merchantId}")
    public MerchantCartItemDTO listCartItem(
            @PathVariable("merchantId") @Min(value = 1, message = "商家主键不能小于1") Long merchantId) {
        return this.omsCartItemClient.listMerchantCartItem(merchantId);
    }
}
