package com.chelvc.cloud.maintain.controller;

import javax.validation.Valid;
import javax.validation.constraints.Min;

import com.chelvc.cloud.vehicle.client.MerchantAuthClient;
import com.chelvc.cloud.vehicle.client.dto.MerchantAuthDTO;
import com.chelvc.cloud.vehicle.client.param.MerchantAuthModifyParam;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

/**
 * 商家认证接口
 *
 * @author liude
 * @date 2023/1/10
 */
@Validated
@RestController
@ResponseWrapping
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class MerchantAuthController {
    private final MerchantAuthClient merchantAuthClient;

    /**
     * 新增商家认证
     *
     * @param param 新增参数
     * @return 商家商家认证主键
     */
    @PostMapping("/merchantAuth")
    public Long addMerchantAuth(@RequestBody @Valid MerchantAuthModifyParam param) {
        return this.merchantAuthClient.addMerchantAuth(param);
    }

    /**
     * 修改商家商家认证
     *
     * @param id    商家商家认证主键
     * @param param 修改参数
     */
    @PutMapping("/merchantAuth/{id}")
    public void updateMerchantAuth(@PathVariable("id") @Min(value = 1, message = "商家主键不能小于1") Long id,
                                   @RequestBody @Valid MerchantAuthModifyParam param) {
        this.merchantAuthClient.updateMerchantAuth(id, param);
    }

    /**
     * 查询商家认证
     */
    @PostMapping("/merchantAuth/queryById")
    public MerchantAuthDTO queryById() {
        return this.merchantAuthClient.queryById();
    }


}
